VR_FOLDER = "/media/internal/Voice Recordings/";
VR_EXTENSION = ".wav";

function MainAssistant() {
}

MainAssistant.prototype.setup = function() {
	
	this.ioHelper = new IOHelper();
	this.utils = new Utils();
	this.timerClock = new TimerClock(this.updateTime.bind(this),1000);
	
	
	
	var menuAttr = {omitDefaultItems: true};
  	var menuModel = {
	    visible: true,
	    items: [
			Mojo.Menu.editItem,	
	    	{label: $L("Help/About"), command: 'do-aboutVoiceRecorder'}
		]
	};
	
	this.controller.setupWidget(Mojo.Menu.appMenu, menuAttr, menuModel);
	
	Mojo.Event.listen(this.controller.get("button-record"), Mojo.Event.tap, 
		this.funcRecordClick.bind(this));

	Mojo.Event.listen(this.controller.get("button-stop"), Mojo.Event.tap, 
		this.funcStopClick.bind(this));	
	
	Mojo.Event.listen(this.controller.get("button-recordings"), Mojo.Event.tap, 
		this.funcRecordingsClick.bind(this));	
	
	Mojo.Event.listen(this.controller.get("list-recent-recordings"), Mojo.Event.listTap, 
		this.listRecentTapped.bindAsEventListener(this));
		
	Mojo.Event.listen(this.controller.get("list-recent-recordings"), Mojo.Event.listDelete, 
		this.listRecentDelete.bindAsEventListener(this));  	 

	this.listAllRecordingsModel = {items:[]}

	this.listRecentRecordingsModel = {items: []}
	
	this.controller.setupWidget(
		"list-recent-recordings", this.attributes = 
		{
        	itemTemplate: 'records/list-item',
        	swipeToDelete: true
    	},
    	this.listRecentRecordingsModel
	);

	this.spinnerModel = {spinning: false};
	this.controller.setupWidget("progress-spinner", this.attributes = {spinnerSize: 'large'}, this.spinnerModel);

	
	this.captureHelper = new CaptureHelper();
	
	Mojo.Log.info('CaptureHelper init: '+this.captureHelper.initDeviceAndFormat(44100));
	
	this.getFileList();
};

MainAssistant.prototype.funcRecordingsClick = function(event){
	this.controller.stageController.pushScene('records',this.listAllRecordingsModel,this);
};


MainAssistant.prototype.funcRecordClick = function(event) {	
	
	var currentDate = new Date()
	var strName = "";
	
	strName = currentDate.getFullYear()+"_"+
			  this.utils.zerosFormat((currentDate.getMonth()+1))+"_"+
			  this.utils.zerosFormat(currentDate.getDate())+"_"+
			  this.utils.zerosFormat(currentDate.getHours())+"-"+
			  this.utils.zerosFormat(currentDate.getMinutes())+"-"+
			  this.utils.zerosFormat(currentDate.getSeconds())+VR_EXTENSION;
	
	
	this.captureHelper.startRecording(strName, 
		function endedCapture(response){
			this.timerClock.stopClockTimer();
			this.getFileList();
		}.bind(this)
	);
	
	
	this.controller.get('button-record-wrapper').style.display = "none";
	this.controller.get('button-stop-wrapper').style.display = "block";
	this.controller.get('button-recordings').style.display = "none";
	this.controller.get('list-group').style.display = "none";
	this.controller.get('text-recording-status').update("Recording...");
	
	this.timerClock.startClockTimer("up", 0);
};


MainAssistant.prototype.funcStopClick = function(event) {
	
	this.captureHelper.stopRecording();
	
	this.controller.get('button-record-wrapper').style.display = "block";
	this.controller.get('button-stop-wrapper').style.display = "none";
	this.controller.get('button-recordings').style.display = "block";
	this.controller.get('list-group').style.display = "block";	
	this.controller.get('text-recording-status').update("Ready to record");
};

MainAssistant.prototype.listRecentTapped = function(event){
	
	var name = this.listRecentRecordingsModel.items[event.index].data;
	
	if (event.originalEvent.target.id == 'button-rename') {
		this.controller.showDialog(
			{template:'inputdialog/inputdialog-dialog', 
			assistant: new InputdialogAssistant(this, name, event.index, false)}
		);
	}
	else{
		this.utils.playRecording(name);
	}
}



MainAssistant.prototype.listRecentDelete = function(event){
	var path = VR_FOLDER + this.listRecentRecordingsModel.items[event.index].data+VR_EXTENSION;
	this.ioHelper.deleteFile(path,
		function(response){
			if (response.returnValue == true){
				this.getFileList();
			}
		}.bind(this)
	);
}




MainAssistant.prototype.getFileList = function(){
	
	this.showWaitScrim(true);
	
	this.ioHelper.scanDirectory(VR_FOLDER,
		function(response){
			if (response.returnValue){
				this.gotFileList(response);
			}
			else{
				this.showWaitScrim(false);
			}
		}.bind(this)
	);
}

MainAssistant.prototype.gotFileList = function(response) {
	
	while (this.listRecentRecordingsModel.items.length>0)
		this.listRecentRecordingsModel.items.pop();
	
	while (this.listAllRecordingsModel.items.length>0)	
		this.listAllRecordingsModel.items.pop();
	
	var recs = response.files;
	var maxIndex = this.utils.isTouchPad() ? 7:2;
	
	if (recs != null && recs.length > 0) {
		
		this.utils.resetArray();
	
		//get file info and sort
		this.utils.synchronousFileInfo(recs,
			function(response){
				Mojo.Log.info(Object.toJSON(response));
				this.listAllRecordingsModel.items = response;
				this.listRecentRecordingsModel.items = response.slice(0,maxIndex);
				this.controller.modelChanged(this.listRecentRecordingsModel);
				this.showWaitScrim(false);
			}.bind(this)
		);
	}
	else{
		this.showWaitScrim(false);
	}
};

MainAssistant.prototype.activate = function(event) {
	/* put in event handlers here that should only be in effect when this scene is active. For
	   example, key handlers that are observing the document */
};

MainAssistant.prototype.deactivate = function(event) {
	/* remove any event handlers you added in activate and do any other cleanup that should happen before
	   this scene is popped or another scene is pushed on top */
};

MainAssistant.prototype.cleanup = function(event) {
	/* this function should do any cleanup needed before the scene is destroyed as 
	   a result of being popped off the scene stack */
};

MainAssistant.prototype.showWaitScrim = function(doShow){
	if (doShow){
		$('wait-scrim').show();
		this.spinnerModel.spinning = true;
		this.controller.modelChanged(this.spinnerModel);
	}
	else{
		$('wait-scrim').hide();
		this.spinnerModel.spinning = false;
		this.controller.modelChanged(this.spinnerModel);
	}
};

MainAssistant.prototype.updateTime = function(time){
	this.controller.get('text-recording-status').update(this.utils.secondsToTime(time));
};


MainAssistant.prototype.handleCommand = function(event){
	if (event.type == Mojo.Event.command) {
	    switch (event.command) {
		
			case 'do-aboutVoiceRecorder':
				this.controller.showAlertDialog({
					allowHTMLMessage: true,
					title: $L("Help/About"),
					message: "<b>Voice Recorder</b><br>version " + Mojo.Controller.appInfo.version +
					"<br>&copy 2011 Ryhor Burakou | Tamspalm<br><br>For help, please visit:" +
					"<br><a href=\'http://ryhor.com/\'>http://ryhor.com/</a>" +
					"<br><br>Publishing support by <br><b>Jonas Dambacher</b> @ TamsPalm DE" +
					"<br><a href=\'http://www.tamspalm.de\'>http://www.tamspalm.de</a>",
					choices: [{
						label: "OK",
						value: "",
						type: 'dismiss'
					}]
				});
				break;
				
				
			case 'do-preferences':
				Mojo.Controller.appController.getActiveStageController().pushScene({name: 'lastfm'});
				break;
		}
	}
};
